mindroot.lib.json_str_block package - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# mindroot.lib.json_str_block package

## Submodules

## mindroot.lib.json_str_block.json_str_block module

mindroot.lib.json_str_block.json_str_block.replace_raw_blocks(jsonish)

  Allows embedding raw text blocks for JSON properties, e.g.:

  [ {“write”: { “filename”: “/test.py”,

    “text”: START_RAW

  def foo():

    print(‘hello world’)

  (with optional END_RAW and continuation of JSON):

  [ {“write”: { “filename”: “/test.py”,

    “text”: START_RAW

  def foo():

    print(‘hello world’)

  END_RAW } } ]

## Module contents